@@ -113,8 +113,8 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   20
-#define XINE_VERSION       "1.1.20.1"
+#define XINE_SUB_VERSION   21
+#define XINE_VERSION       "1.1.21"
 
 /*
  * pre-init the xine engine
@@ -134,6 +134,12 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
  */
 xine_t *xine_new (void) XINE_PROTECTED;
 
+/* allow the setting of some flags before xine_init
+ * FIXME-ABI: this is currently GLOBAL
+ */
+void xine_set_flags (xine_t *, int) XINE_PROTECTED __attribute__((weak));
+#define XINE_FLAG_NO_WRITE_CACHE		1
+
 /*
  * post_init the xine engine
  */
