@@ -33,10 +33,6 @@
 #  include "../../libffmpeg/libavcodec/avcodec.h"
 #endif
 
-#if LIBAVCODEC_VERSION_MAJOR > 51
-#define bits_per_sample bits_per_coded_sample
-#endif
-
 typedef struct ff_codec_s {
   uint32_t          type;
   enum CodecID      id;
