@@ -1041,7 +1041,7 @@ static input_plugin_t *http_class_get_instance (input_class_t *cls_gen, xine_str
   this = calloc(1, sizeof(http_input_plugin_t));
 
   if (!strncasecmp (mrl, "peercast://pls/", 15)) {
-    asprintf (&this->mrl, "http://127.0.0.1:7144/stream/%s", mrl+15);
+    this->mrl = _x_asprintf ("http://127.0.0.1:7144/stream/%s", mrl+15);
   } else {
     this->mrl = strdup (mrl);
   }
