@@ -701,9 +701,13 @@ static void directfb_display_frame (vo_driver_t *this_gen, vo_frame_t *frame_gen
     lprintf ("failed=0x%08x.\n", failed);
   }
 
-  if (this->sc.delivered_width  != frame->width  ||
-      this->sc.delivered_height != frame->height ||
-      this->sc.delivered_ratio  != frame->ratio)
+  if ( (frame->width != this->sc.delivered_width)
+       || (frame->height != this->sc.delivered_height)
+       || (frame->ratio != this->sc.delivered_ratio)
+       || (frame->vo_frame.crop_left != this->sc.crop_left)
+       || (frame->vo_frame.crop_right != this->sc.crop_right)
+       || (frame->vo_frame.crop_top != this->sc.crop_top)
+       || (frame->vo_frame.crop_bottom != this->sc.crop_bottom) )
   {
     lprintf ("forcing redraw.\n");
     this->sc.force_redraw = 1;
