@@ -770,6 +770,8 @@ static void xv_display_frame (vo_driver_t *this_gen, vo_frame_t *frame_gen) {
 static int xv_get_property (vo_driver_t *this_gen, int property) {
   xv_driver_t *this = (xv_driver_t *) this_gen;
 
+  if ((property < 0) || (property >= VO_NUM_PROPERTIES)) return (0);
+
   switch (property) {
     case VO_PROP_WINDOW_WIDTH:
       this->props[property].value = this->sc.gui_width;
@@ -810,6 +812,8 @@ static int xv_set_property (vo_driver_t *this_gen,
 			    int property, int value) {
   xv_driver_t *this = (xv_driver_t *) this_gen;
 
+  if ((property < 0) || (property >= VO_NUM_PROPERTIES)) return 0;
+
   if (this->props[property].atom != XCB_NONE) {
     xcb_xv_get_port_attribute_cookie_t get_attribute_cookie;
     xcb_xv_get_port_attribute_reply_t *get_attribute_reply;
@@ -899,6 +903,11 @@ static void xv_get_property_min_max (vo_driver_t *this_gen,
 				     int property, int *min, int *max) {
   xv_driver_t *this = (xv_driver_t *) this_gen;
 
+  if ((property < 0) || (property >= VO_NUM_PROPERTIES)) {
+    *min = *max = 0;
+    return;
+  }
+
   *min = this->props[property].min;
   *max = this->props[property].max;
 }
@@ -968,7 +977,7 @@ static int xv_gui_data_exchange (vo_driver_t *this_gen,
 
   case XINE_GUI_SEND_DRAWABLE_CHANGED:
     pthread_mutex_lock(&this->main_mutex);
-    this->window = (xcb_window_t) data;
+    this->window = (xcb_window_t) (long) data;
     xcb_free_gc(this->connection, this->gc);
     this->gc = xcb_generate_id(this->connection);
     xcb_create_gc(this->connection, this->gc, this->window, 0, NULL);
@@ -1130,9 +1139,9 @@ static int xv_check_yv12(xcb_connection_t *connection, xcb_xv_port_t port) {
 static void xv_check_capability (xv_driver_t *this,
 				 int property, xcb_xv_attribute_info_t *attr,
 				 int base_id,
-				 char *config_name,
-				 char *config_desc,
-				 char *config_help) {
+				 const char *config_name,
+				 const char *config_desc,
+				 const char *config_help) {
   int          int_default;
   cfg_entry_t *entry;
   const char  *str_prop = xcb_xv_attribute_info_name(attr);
