@@ -1754,6 +1754,8 @@ static void xxmc_display_frame (vo_driver_t *this_gen, vo_frame_t *frame_gen)
 static int xxmc_get_property (vo_driver_t *this_gen, int property) {
   xxmc_driver_t *this = (xxmc_driver_t *) this_gen;
 
+  if ((property < 0) || (property >= VO_NUM_PROPERTIES)) return 0;
+
   switch (property) {
   case VO_PROP_WINDOW_WIDTH:
     this->props[property].value = this->sc.gui_width;
@@ -1804,6 +1806,8 @@ static int xxmc_set_property (vo_driver_t *this_gen,
 			      int property, int value) {
   xxmc_driver_t *this = (xxmc_driver_t *) this_gen;
 
+  if ((property < 0) || (property >= VO_NUM_PROPERTIES)) return 0;
+
   if (this->props[property].atom != None) {
 
     /* value is out of bound */
@@ -1892,6 +1896,10 @@ static void xxmc_get_property_min_max (vo_driver_t *this_gen,
 				       int property, int *min, int *max) {
   xxmc_driver_t *this = (xxmc_driver_t *) this_gen;
 
+  if ((property < 0) || (property >= VO_NUM_PROPERTIES)) {
+    *min = *max = 0;
+    return;
+  }
   *min = this->props[property].min;
   *max = this->props[property].max;
 }
