@@ -111,6 +111,8 @@ xine_event_queue_t *xine_event_new_queue (xine_stream_t *stream) {
 
   xine_event_queue_t *queue;
 
+  _x_refcounter_inc(stream->refcounter);
+
   queue = malloc (sizeof (xine_event_queue_t));
 
   pthread_mutex_init (&queue->lock, NULL);
@@ -186,6 +188,8 @@ void xine_event_dispose_queue (xine_event_queue_t *queue) {
     free (queue->listener_thread);
   }
 
+  _x_refcounter_dec(stream->refcounter);
+
   /*
    * clean up pending events
    */
@@ -193,6 +197,7 @@ void xine_event_dispose_queue (xine_event_queue_t *queue) {
   while ( (event = xine_event_get (queue)) ) {
     xine_event_free (event);
   }
+  xine_list_delete(queue->events);
 
   pthread_mutex_destroy(&queue->lock);
   pthread_cond_destroy(&queue->new_event);
